package com.ruoyi.gysl.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itextpdf.text.DocumentException;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.gysl.entity.Mmm;
import com.ruoyi.gysl.entity.request.MmmRequest;
import com.ruoyi.gysl.service.MmmService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDateTime;

/**
 * 单片材料管理(MmmController)表控制层
 *
 * @author User
 */
@Api(tags = "单片材料管理")
@RestController
@RequestMapping("gysl/mmm")
public class MmmController extends BaseController {
    @Resource
    private MmmService mmmService;

    /**
     * 分页查询所有数据
     *
     * @param req 分页对象
     * @return 查询结果
     */
    @ApiOperation(value = "分页查询")
    @GetMapping("/page")
    public AjaxResult queryByPage(MmmRequest req) {
        Page<Mmm> page = new Page<>();
        page.setCurrent(req.getCurrent());
        page.setSize(req.getSize());
        return success(mmmService.page(page, req));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条数据", response = Mmm.class)
    public AjaxResult selectOne(@PathVariable Integer id) {
        return success(this.mmmService.getById(id));
    }


    /**
     * 编辑数据
     *
     * @param mmm 实体对象
     * @return 修改结果
     */
    @PostMapping("/edit")
    @ApiOperation("修改数据")
    public AjaxResult update(@RequestBody Mmm mmm) {
        //上传id 上传者 上传时间
        mmm.setUpdateTime(LocalDateTime.now());
        mmm.setUpdateBy(getUsername());
        mmm.setUpdateId(getUserId());
        return success(this.mmmService.updateById(mmm));
    }


    /**
     * 添加
     */
    @PostMapping("/add")
    @ApiOperation("新增数据")
    public AjaxResult insert(@RequestBody Mmm mmm) {
        //创建id 创建者 创建时间
        mmm.setCreateBy(getUsername());
        mmm.setCreateId(getUserId());
        mmm.setCreateTime(LocalDateTime.now());
        return success(this.mmmService.save(mmm));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @ApiOperation("删除数据")
    @DeleteMapping("/delete/{id}")
    public AjaxResult deleteById(@PathVariable Integer id) {
        return success(this.mmmService.removeById(id));
    }


    /**
     *
     * @param id 查找
     * @return  导出的PDF
     * @throws IOException
     */
    @ApiOperation("PDF导出")
    @GetMapping("/PDF/{id}")
    public ResponseEntity<byte[]> exportPdf(@PathVariable Integer id) throws IOException, DocumentException {
        Mmm item = mmmService.getById(id);
        //路径
        String path = "C:\\Users\\User\\Desktop\\pdf模板.pdf";
        //PDF填充
        byte[] pdfBytes = mmmService.fillPdfTemplate(path,item);

        // 设置响应头
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_PDF);
        headers.setContentDispositionFormData("attachment", item.getDocumentTitle() + ".pdf");
        headers.setContentLength(pdfBytes.length);

        return new ResponseEntity<>(pdfBytes, headers, HttpStatus.OK);
    }

}
